PrimitiveCall

Enum PrimitiveCall 

pub enum PrimitiveCall {
Show 21 variants AsPtr, AsMutPtr, AsPtrRange, AsMutPtrRange, PtrCast, PtrAdd, PtrSub, PtrOffset, PtrByteAdd, PtrByteSub, PtrByteOffset, PtrRead, PtrWrite, Len, MaybeUninitUninit, AlignOf, SizeOf, FromRawParts, FromRawPartsMut, SplitAt, SplitAtMut,
}
Std/core primitive calls with verifier-specific transfer functions.

Variants



AsPtr



AsMutPtr



AsPtrRange



AsMutPtrRange



PtrCast



PtrAdd



PtrSub



PtrOffset



PtrByteAdd



PtrByteSub



PtrByteOffset



PtrRead



PtrWrite



Len



MaybeUninitUninit



AlignOf



SizeOf



FromRawParts



FromRawPartsMut



SplitAt



SplitAtMut

Implementations

Source

impl PrimitiveCall

pub fn classify(name: &str) -> Option<Self>

Classify a stable rustc def-path string as a known primitive call.

pub fn is_as_ptr_like(self) -> bool

Return true for calls that extract a raw pointer from an aggregate.

pub fn is_pointer_add_like(self) -> bool

Return true for pointer arithmetic calls with base + offset * stride.

pub fn is_pointer_sub_like(self) -> bool

Return true for pointer arithmetic calls with base - offset * stride.

pub fn is_pointer_arithmetic(self) -> bool

Return true for any pointer arithmetic primitive.

pub fn is_byte_pointer_arithmetic(self) -> bool

Return true when the arithmetic count is measured in bytes.

pub fn is_signed_pointer_arithmetic(self) -> bool

Return true when the arithmetic count can be negative.

pub fn is_layout_constant(self) -> bool

Return true for compile-time layout constant producers.