pub enum PrimitiveCall {
Show 21 variants
AsPtr,
AsMutPtr,
AsPtrRange,
AsMutPtrRange,
PtrCast,
PtrAdd,
PtrSub,
PtrOffset,
PtrByteAdd,
PtrByteSub,
PtrByteOffset,
PtrRead,
PtrWrite,
Len,
MaybeUninitUninit,
AlignOf,
SizeOf,
FromRawParts,
FromRawPartsMut,
SplitAt,
SplitAtMut,
}Expand description
Std/core primitive calls with verifier-specific transfer functions.
Variants
AsPtr
AsMutPtr
AsPtrRange
AsMutPtrRange
PtrCast
PtrAdd
PtrSub
PtrOffset
PtrByteAdd
PtrByteSub
PtrByteOffset
PtrRead
PtrWrite
Len
MaybeUninitUninit
AlignOf
SizeOf
FromRawParts
FromRawPartsMut
SplitAt
SplitAtMut
Implementations
Sourceimpl PrimitiveCall
impl PrimitiveCall
Sourcepub fn classify(name: &str) -> Option<Self>
pub fn classify(name: &str) -> Option<Self>
Classify a stable rustc def-path string as a known primitive call.
Sourcepub fn is_as_ptr_like(self) -> bool
pub fn is_as_ptr_like(self) -> bool
Return true for calls that extract a raw pointer from an aggregate.
Sourcepub fn is_pointer_add_like(self) -> bool
pub fn is_pointer_add_like(self) -> bool
Return true for pointer arithmetic calls with base + offset * stride.
Sourcepub fn is_pointer_sub_like(self) -> bool
pub fn is_pointer_sub_like(self) -> bool
Return true for pointer arithmetic calls with base - offset * stride.
Sourcepub fn is_pointer_arithmetic(self) -> bool
pub fn is_pointer_arithmetic(self) -> bool
Return true for any pointer arithmetic primitive.
Sourcepub fn is_byte_pointer_arithmetic(self) -> bool
pub fn is_byte_pointer_arithmetic(self) -> bool
Return true when the arithmetic count is measured in bytes.
Sourcepub fn is_signed_pointer_arithmetic(self) -> bool
pub fn is_signed_pointer_arithmetic(self) -> bool
Return true when the arithmetic count can be negative.
Sourcepub fn is_layout_constant(self) -> bool
pub fn is_layout_constant(self) -> bool
Return true for compile-time layout constant producers.